@@ -9,7 +9,7 @@
  */
 
 /*
- * Copyright (C) 2006-2016 Oracle Corporation
+ * Copyright (C) 2006-2019 Oracle Corporation
  *
  * This file is part of VirtualBox Open Source Edition (OSE), as
  * available from http://www.virtualbox.org. This file is free software;
@@ -20,8 +20,11 @@
  * hope that it will be useful, but WITHOUT ANY WARRANTY of any kind.
  */
 
-#ifndef ___VUSBInternal_h
-#define ___VUSBInternal_h
+#ifndef VBOX_INCLUDED_SRC_USB_VUSBInternal_h
+#define VBOX_INCLUDED_SRC_USB_VUSBInternal_h
+#ifndef RT_WITHOUT_PRAGMA_ONCE
+# pragma once
+#endif
 
 #include <VBox/cdefs.h>
 #include <VBox/types.h>
@@ -95,8 +98,6 @@ typedef struct VUSBURBVUSBINT
     DECLCALLBACKMEMBER(void, pfnFree)(PVUSBURB pUrb);
     /** Submit timestamp. (logging only) */
     uint64_t        u64SubmitTS;
-    /** Opaque data holder when this is an URB from a buffered pipe. */
-    void            *pvBuffered;
 } VUSBURBVUSBINT;
 
 /**
@@ -146,11 +147,6 @@ typedef struct vusb_ctrl_extra
 void vusbMsgFreeExtraData(PVUSBCTRLEXTRA pExtra);
 void vusbMsgResetExtraData(PVUSBCTRLEXTRA pExtra);
 
-/** Opaque VUSB buffered pipe management handle. */
-typedef struct VUSBBUFFEREDPIPEINT *VUSBBUFFEREDPIPE;
-/** Pointer to a VUSB buffered pipe handle. */
-typedef VUSBBUFFEREDPIPE *PVUSBBUFFEREDPIPE;
-
 /**
  * A VUSB pipe
  */
@@ -164,8 +160,10 @@ typedef struct vusb_pipe
     RTCRITSECT          CritSectCtrl;
     /** Count of active async transfers. */
     volatile uint32_t   async;
-    /** Pipe buffer - only valid for isochronous endpoints. */
-    VUSBBUFFEREDPIPE    hBuffer;
+    /** Last scheduled frame - only valid for isochronous IN endpoints. */
+    uint32_t            uLastFrameIn;
+    /** Last scheduled frame - only valid for isochronous OUT endpoints. */
+    uint32_t            uLastFrameOut;
 } VUSBPIPE;
 /** Pointer to a VUSB pipe structure. */
 typedef VUSBPIPE *PVUSBPIPE;
@@ -484,7 +482,7 @@ AssertCompileMemberAlignment(VUSBROOTHUB, Total, 8);
 #endif
 
 /** Converts a pointer to VUSBROOTHUB::IRhConnector to a PVUSBROOTHUB. */
-#define VUSBIROOTHUBCONNECTOR_2_VUSBROOTHUB(pInterface) (PVUSBROOTHUB)( (uintptr_t)(pInterface) - RT_OFFSETOF(VUSBROOTHUB, IRhConnector) )
+#define VUSBIROOTHUBCONNECTOR_2_VUSBROOTHUB(pInterface) (PVUSBROOTHUB)( (uintptr_t)(pInterface) - RT_UOFFSETOF(VUSBROOTHUB, IRhConnector) )
 
 /**
  * URB cancellation modes
@@ -525,48 +523,6 @@ DECLHIDDEN(uint64_t) vusbRhR3ProcessFrame(PVUSBROOTHUB pThis, bool fCallback);
 
 int  vusbUrbQueueAsyncRh(PVUSBURB pUrb);
 
-/**
- * Completes an URB from a buffered pipe.
- *
- * @returns nothing.
- * @param   pUrb        The URB to complete.
- */
-DECLHIDDEN(void) vusbBufferedPipeCompleteUrb(PVUSBURB pUrb);
-
-/**
- * Creates a new buffered pipe.
- *
- * @returns VBox status code.
- * @retval  VERR_NOT_SUPPORTED if buffering is not supported for the given pipe.
- * @param   pDev         The device instance the pipe is associated with.
- * @param   pPipe        The pipe to buffer.
- * @param   enmDirection The direction for the buffering.
- * @param   enmSpeed     USB device speed.
- * @param   cLatencyMs   The maximum latency the buffering should introduce, this influences
- *                       the amount of data to buffer.
- * @param   phBuffer     Where to store the handle to the buffer on success.
- */
-DECLHIDDEN(int)  vusbBufferedPipeCreate(PVUSBDEV pDev, PVUSBPIPE pPipe, VUSBDIRECTION enmDirection,
-                                        VUSBSPEED enmSpeed, uint32_t cLatencyMs,
-                                        PVUSBBUFFEREDPIPE phBuffer);
-
-/**
- * Destroys a buffered pipe, freeing all acquired resources.
- *
- * @returns nothing.
- * @param   hBuffer     The buffered pipe handle.
- */
-DECLHIDDEN(void) vusbBufferedPipeDestroy(VUSBBUFFEREDPIPE hBuffer);
-
-/**
- * Submits a URB from the HCD which is subject to buffering.
- *
- * @returns VBox status code.
- * @param   hBuffer     The buffered pipe handle.
- * @param   pUrb        The URB from the HCD which is subject to buffering.
- */
-DECLHIDDEN(int)  vusbBufferedPipeSubmitUrb(VUSBBUFFEREDPIPE hBuffer, PVUSBURB pUrb);
-
 /**
  * Initializes the given URB pool.
  *
@@ -787,5 +743,5 @@ extern const VUSBDESCENDPOINTEX g_Endpoint0;
 extern const VUSBDESCCONFIGEX g_Config0;
 
 RT_C_DECLS_END
-#endif
+#endif /* !VBOX_INCLUDED_SRC_USB_VUSBInternal_h */
 
