@@ -4,7 +4,7 @@
  */
 
 /*
- * Copyright (C) 2006-2016 Oracle Corporation
+ * Copyright (C) 2006-2019 Oracle Corporation
  *
  * This file is part of VirtualBox Open Source Edition (OSE), as
  * available from http://www.virtualbox.org. This file is free software;
@@ -112,7 +112,7 @@ int pdmR3DrvInit(PVM pVM)
 {
     LogFlow(("pdmR3DrvInit:\n"));
 
-    AssertRelease(!(RT_OFFSETOF(PDMDRVINS, achInstanceData) & 15));
+    AssertRelease(!(RT_UOFFSETOF(PDMDRVINS, achInstanceData) & 15));
     PPDMDRVINS pDrvInsAssert; NOREF(pDrvInsAssert);
     AssertCompile(sizeof(pDrvInsAssert->Internal.s) <= sizeof(pDrvInsAssert->Internal.padding));
     AssertRelease(sizeof(pDrvInsAssert->Internal.s) <= sizeof(pDrvInsAssert->Internal.padding));
@@ -424,7 +424,7 @@ static int pdmR3DrvMaybeTransformChain(PVM pVM, PPDMDRVINS pDrvAbove, PPDMLUN pL
         rc = CFGMR3GetName(pCurTrans, szCurTransNm, sizeof(szCurTransNm));
         AssertLogRelRCReturn(rc, rc);
 
-        /** @cfgm{/PDM/DriverTransformations/\<name\>/Device,string,*}
+        /** @cfgm{/PDM/DriverTransformations/&lt;name&gt;/Device,string,*}
          * One or more simple wildcard patters separated by '|' for matching
          * the devices this transformation rule applies to. */
         char *pszMultiPat;
@@ -435,7 +435,7 @@ static int pdmR3DrvMaybeTransformChain(PVM pVM, PPDMDRVINS pDrvAbove, PPDMLUN pL
         if (!fMatch)
             continue;
 
-        /** @cfgm{/PDM/DriverTransformations/\<name\>/LUN,string,*}
+        /** @cfgm{/PDM/DriverTransformations/&lt;name&gt;/LUN,string,*}
          * One or more simple wildcard patters separated by '|' for matching
          * the LUNs this transformation rule applies to. */
         rc = CFGMR3QueryStringAllocDef(pCurTrans, "LUN", &pszMultiPat, "*");
@@ -445,12 +445,12 @@ static int pdmR3DrvMaybeTransformChain(PVM pVM, PPDMDRVINS pDrvAbove, PPDMLUN pL
         if (!fMatch)
             continue;
 
-        /** @cfgm{/PDM/DriverTransformations/\<name\>/BelowDriver,string,*}
+        /** @cfgm{/PDM/DriverTransformations/&lt;name&gt;/BelowDriver,string,*}
          * One or more simple wildcard patters separated by '|' for matching the
          * drivers the transformation should be applied below.  This means, that
          * when the drivers matched here attached another driver below them, the
-         * transformation will be applied.  To represent the device, '\<top\>' is
-         * used. */
+         * transformation will be applied.  To represent the device, '&lt;top&gt;'
+         * is used. */
         rc = CFGMR3QueryStringAllocDef(pCurTrans, "BelowDriver", &pszMultiPat, "*");
         AssertLogRelRCReturn(rc, rc);
         fMatch = RTStrSimplePatternMultiMatch(pszMultiPat, RTSTR_MAX, pszAbove, RTSTR_MAX, NULL);
@@ -458,7 +458,7 @@ static int pdmR3DrvMaybeTransformChain(PVM pVM, PPDMDRVINS pDrvAbove, PPDMLUN pL
         if (!fMatch)
             continue;
 
-        /** @cfgm{/PDM/DriverTransformations/\<name\>/AboveDriver,string,*}
+        /** @cfgm{/PDM/DriverTransformations/&lt;name&gt;/AboveDriver,string,*}
          * One or more simple wildcard patters separated by '|' for matching the
          * drivers the transformation should be applie above or at (depending on
          * the action).  The value being matched against here is the driver that
@@ -482,7 +482,7 @@ static int pdmR3DrvMaybeTransformChain(PVM pVM, PPDMDRVINS pDrvAbove, PPDMLUN pL
          * We've got a match! Now, what are we supposed to do?
          */
         /** @cfgm{/PDM/DriverTransformations/&lt;name&gt;/Action,string,inject}
-         * The action that the the transformation takes.  Possible values are:
+         * The action that the transformation takes.  Possible values are:
          *      - inject
          *      - mergeconfig: This merges and the content of the 'Config' key under the
          *        transformation into the driver's own 'Config' key, replacing any
@@ -700,7 +700,7 @@ int pdmR3DrvInstantiate(PVM pVM, PCFGMNODE pNode, PPDMIBASE pBaseInterface, PPDM
                 /*
                  * Allocate the driver instance.
                  */
-                size_t cb = RT_OFFSETOF(PDMDRVINS, achInstanceData[pDrv->pReg->cbInstance]);
+                size_t cb = RT_UOFFSETOF_DYN(PDMDRVINS, achInstanceData[pDrv->pReg->cbInstance]);
                 cb = RT_ALIGN_Z(cb, 16);
                 bool const fHyperHeap = !!(pDrv->pReg->fFlags & (PDM_DRVREG_FLAGS_R0 | PDM_DRVREG_FLAGS_RC));
                 PPDMDRVINS pNew;
@@ -745,7 +745,7 @@ int pdmR3DrvInstantiate(PVM pVM, PCFGMNODE pNode, PPDMIBASE pBaseInterface, PPDM
                         AssertReleaseRCReturn(rc, rc);
                     }
                     if (   (pDrv->pReg->fFlags & PDM_DRVREG_FLAGS_RC)
-                        && !HMIsEnabled(pVM))
+                        && VM_IS_RAW_MODE_ENABLED(pVM))
                     {
                         pNew->pvInstanceDataR0      = MMHyperR3ToRC(pVM, &pNew->achInstanceData[0]);
                         rc = PDMR3LdrGetSymbolRC(pVM, NULL, "g_pdmRCDrvHlp", &pNew->pHlpRC);
@@ -993,7 +993,7 @@ void pdmR3DrvDestroyChain(PPDMDRVINS pDrvIns, uint32_t fFlags)
 
         /* Finally, the driver it self. */
         bool fHyperHeap = pCur->Internal.s.fHyperHeap;
-        ASMMemFill32(pCur, RT_OFFSETOF(PDMDRVINS, achInstanceData[pCur->pReg->cbInstance]), 0xdeadd0d0);
+        ASMMemFill32(pCur, RT_UOFFSETOF_DYN(PDMDRVINS, achInstanceData[pCur->pReg->cbInstance]), 0xdeadd0d0);
         if (fHyperHeap)
             MMHyperFree(pVM, pCur);
         else
